==> drools-quarkus-unit-example-0.6.0-sources.jar: org/drools/project/model/ProjectModel.java <==
package org.drools.project.model;

import org.drools.model.Model;
import org.kie.api.builder.ReleaseId;
import org.drools.compiler.kproject.ReleaseIdImpl;

public class ProjectModel implements org.drools.modelcompiler.CanonicalKieModuleModel {

    @Override
    public String getVersion() {
        return "0.6.0";
    }

    @Override
    public java.util.List<Model> getModels() {
        return java.util.Arrays.asList(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit(), new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringService(), new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_LoggerService());
    }

    @Override
    public java.util.List<Model> getModelsForKieBase(String kieBaseName) {
        switch (kieBaseName) {
            case "org$kie$kogito$rules$alerting$LoggerServiceKieBase": return java.util.Arrays.asList(new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_LoggerService());
            case "org$kie$kogito$queries$AdultUnitKieBase": return java.util.Arrays.asList(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit());
            case "defaultKieBase": return getModels();
            case "org$kie$kogito$rules$alerting$MonitoringServiceKieBase": return java.util.Arrays.asList(new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringService());
        }
        throw new IllegalArgumentException("Unknown KieBase: " + kieBaseName);
    }

    @Override
    public ReleaseId getReleaseId() {
        return new ReleaseIdImpl("dummy", "dummy", "0.0.0");
    }

@Override()
public org.kie.api.builder.model.KieModuleModel getKieModuleModel() {
    org.kie.api.builder.model.KieModuleModel kModuleModel = org.kie.api.KieServices.get().newKieModuleModel();
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$rules$alerting$LoggerServiceKieBase");
    kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.addPackage("org.kie.kogito.rules.alerting");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession = kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.newKieSessionModel("org$kie$kogito$rules$alerting$LoggerServiceKieSession");
    kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$queries$AdultUnitKieBase");
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.addPackage("org.kie.kogito.queries");
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.setSessionsPool(org.kie.api.conf.SessionsPoolOption.get(1));
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession = kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.newKieSessionModel("org$kie$kogito$queries$AdultUnitKieSession");
    kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_defaultKieBase = kModuleModel.newKieBaseModel("defaultKieBase");
    kieBaseModel_defaultKieBase.setDefault(true);
    kieBaseModel_defaultKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_defaultKieBase.addPackage("*");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_defaultStatelessKieSession = kieBaseModel_defaultKieBase.newKieSessionModel("defaultStatelessKieSession");
    kieSessionModel_defaultStatelessKieSession.setDefault(true);
    kieSessionModel_defaultStatelessKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATELESS);
    kieSessionModel_defaultStatelessKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieSessionModel kieSessionModel_defaultKieSession = kieBaseModel_defaultKieBase.newKieSessionModel("defaultKieSession");
    kieSessionModel_defaultKieSession.setDefault(true);
    kieSessionModel_defaultKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_defaultKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$rules$alerting$MonitoringServiceKieBase");
    kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.addPackage("org.kie.kogito.rules.alerting");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession = kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.newKieSessionModel("org$kie$kogito$rules$alerting$MonitoringServiceKieSession");
    kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    return kModuleModel;
}
}

==> drools-quarkus-unit-example-0.7.0-sources.jar: org/drools/project/model/ProjectModel.java <==
package org.drools.project.model;

import org.drools.model.Model;
import org.kie.api.builder.ReleaseId;
import org.drools.compiler.kproject.ReleaseIdImpl;

public class ProjectModel implements org.drools.modelcompiler.CanonicalKieModuleModel {

    @Override
    public String getVersion() {
        return "0.7.0";
    }

    @Override
    public java.util.List<Model> getModels() {
        return java.util.Arrays.asList(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit(), new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringService(), new org.kie.kogito.candrink.Rules398ABF96D36EB693F10D11FFA4BAA3D0_CanDrinkUnit(), new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_LoggerService());
    }

    public java.util.List<Model> getModelsForKieBase(String kieBaseName) {
        switch (kieBaseName) {
            case "org$kie$kogito$candrink$CanDrinkUnitKieBase": return java.util.Arrays.asList(new org.kie.kogito.candrink.Rules398ABF96D36EB693F10D11FFA4BAA3D0_CanDrinkUnit());
            case "org$kie$kogito$rules$alerting$LoggerServiceKieBase": return java.util.Arrays.asList(new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_LoggerService());
            case "org$kie$kogito$queries$AdultUnitKieBase": return java.util.Arrays.asList(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit());
            case "defaultKieBase": return getModels();
            case "org$kie$kogito$rules$alerting$MonitoringServiceKieBase": return java.util.Arrays.asList(new org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringService());
        }
        throw new IllegalArgumentException("Unknown KieBase: " + kieBaseName);
    }

    @Override
    public ReleaseId getReleaseId() {
        return new ReleaseIdImpl("dummy", "dummy", "0.0.0");
    }

@Override()
public org.kie.api.builder.model.KieModuleModel getKieModuleModel() {
    org.kie.api.builder.model.KieModuleModel kModuleModel = org.kie.api.KieServices.get().newKieModuleModel();
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$candrink$CanDrinkUnitKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$candrink$CanDrinkUnitKieBase");
    kieBaseModel_org$kie$kogito$candrink$CanDrinkUnitKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$candrink$CanDrinkUnitKieBase.addPackage("org.kie.kogito.candrink");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$candrink$CanDrinkUnitKieSession = kieBaseModel_org$kie$kogito$candrink$CanDrinkUnitKieBase.newKieSessionModel("org$kie$kogito$candrink$CanDrinkUnitKieSession");
    kieSessionModel_org$kie$kogito$candrink$CanDrinkUnitKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$candrink$CanDrinkUnitKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$rules$alerting$LoggerServiceKieBase");
    kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.addPackage("org.kie.kogito.rules.alerting");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession = kieBaseModel_org$kie$kogito$rules$alerting$LoggerServiceKieBase.newKieSessionModel("org$kie$kogito$rules$alerting$LoggerServiceKieSession");
    kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$rules$alerting$LoggerServiceKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$queries$AdultUnitKieBase");
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.addPackage("org.kie.kogito.queries");
    kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.setSessionsPool(org.kie.api.conf.SessionsPoolOption.get(1));
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession = kieBaseModel_org$kie$kogito$queries$AdultUnitKieBase.newKieSessionModel("org$kie$kogito$queries$AdultUnitKieSession");
    kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$queries$AdultUnitKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_defaultKieBase = kModuleModel.newKieBaseModel("defaultKieBase");
    kieBaseModel_defaultKieBase.setDefault(true);
    kieBaseModel_defaultKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_defaultKieBase.addPackage("*");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_defaultStatelessKieSession = kieBaseModel_defaultKieBase.newKieSessionModel("defaultStatelessKieSession");
    kieSessionModel_defaultStatelessKieSession.setDefault(true);
    kieSessionModel_defaultStatelessKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATELESS);
    kieSessionModel_defaultStatelessKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieSessionModel kieSessionModel_defaultKieSession = kieBaseModel_defaultKieBase.newKieSessionModel("defaultKieSession");
    kieSessionModel_defaultKieSession.setDefault(true);
    kieSessionModel_defaultKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_defaultKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    org.kie.api.builder.model.KieBaseModel kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase = kModuleModel.newKieBaseModel("org$kie$kogito$rules$alerting$MonitoringServiceKieBase");
    kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.setEventProcessingMode(org.kie.api.conf.EventProcessingOption.CLOUD);
    kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.addPackage("org.kie.kogito.rules.alerting");
    org.kie.api.builder.model.KieSessionModel kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession = kieBaseModel_org$kie$kogito$rules$alerting$MonitoringServiceKieBase.newKieSessionModel("org$kie$kogito$rules$alerting$MonitoringServiceKieSession");
    kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession.setType(org.kie.api.builder.model.KieSessionModel.KieSessionType.STATEFUL);
    kieSessionModel_org$kie$kogito$rules$alerting$MonitoringServiceKieSession.setClockType(org.kie.api.runtime.conf.ClockTypeOption.get("realtime"));
    return kModuleModel;
}
}
